# -*- coding: utf-8 -*-

"""
Package contetant l'API pydiploy permettant l'automatisation des déploiements et de la gestion des applications Python
dans des environnements multiples comme le test, la pre-production, la prodcution ou même le développement
"""

from pydiploy import django, prepare, require, params
